# Modernizing Your Existing Adobe Experience Manager Sites Codebase

## Table of Contents

* [Lab Overview](#lab-overview)
* [Lesson 0 - Software Installation](lessons/lesson-0.md)
* [Lesson 1 - Editable Templates](lessons/lesson-1.md)
* [Lesson 2 - Component Updates](lessons/lesson-2.md)
* [Lesson 3 - Policy Updates](lessons/lesson-3.md)
* [Lesson 4 - Dialog Updates](lessons/lesson-4.md)
* [Troubleshooting Steps](troubleshooting.md)
* [Next Steps](next-steps.md)
* [Additional Resources](additional-resources.md)

## Lab Overview

A number of our customers still rely on the Classic UI for making authoring updates. This means the sites implementation doesn't make use of many of the latest features of the AEM product. Other customers may be operating in the Touch-Enabled UI, but they are still developing new content using static templates. Updating to Editable Templates requires review, planning, and a properly executed project. This lab is intended to help jump start that process, providing guidance and tools to reduce the effort to modernize your AEM Sites implementations.   

In this lab we will learn about the process of migrating Experience Manager Sites pages. First we will review a site implemented using legacy static templates, and plan a migration to modern editable template-based pages. Using this information we will analyze the existing content for changes necessary to migrate to a new template. Then we will update the pages, to leverage the responsive grid, policies, and Touch-enabled UI capabilities in AEM. From there we will explore how to update code and configurations, making them compatible with modern AEM Sites development paradigms. Finally, we will adjust existing content to work with the updated code.

### Key Takeaways

* Identify & review considerations for converting static template to editable templates
* Analyze existing content for changes necessary to migrate to new template structure
* Hands-on updating a template to use new AEM patterns & components.
* Hands-on converting components to AEM Core Components
* Hands-on importing of Classic Designs as Editable Template Policies
* Hands-on updating of Classic dialog to Coral 3 Dialog

### Prerequisites

* AEM 6.5 L22
* All other files/code are provided in the `packages` directory.

## Lessons

If you're accomplishing this lab at Summit, go ahead and skip over to [Lesson 1](/lessons/lesson-1.md) and start the Page conversion process.

Otherwise, if you're doing this post-summit, follow [Lesson 0](/lessons/lesson-0.md) to set up your AEM instance and complete the lessons and exercises. 

