# Modernizing Your Existing Adobe Experience Manager Sites Codebase

## Table of Contents

* [Lab Overview](../README.md#lab-overview)
* [Lesson 0 - Software Installation](lesson-0.md)
* [Lesson 1 - Editable Templates](lesson-1.md)
* [Lesson 2 - Component Updates](lesson-2.md)
* [Lesson 3 - Policy Updates](lesson-3.md)
* [Lesson 4 - Dialog Updates](lesson-4.md)
* [Troubleshooting Steps](../troubleshooting.md)
* [Next Steps](../next-steps.md)
* [Additional Resources](../additional-resources.md)

## Lesson 1 - Editable Templates

### Lesson Context

This lesson reviews an existing site which was implemented using Static Templates and identify identifies the appropriate steps to migrate them to Editable Templates. Afterwards, we'll use the *Page Template/Structure Conversion Tool* to convert a page.

### Scenario

The Geometrixx Shapes team has decided to upgrade their Static Templates to the new AEM Editable Templates. They want to start with converting the `Home Page` template over to a new structure.

They've already set up an initial code using the Adobe Maven AEM Archetype. The next steps are to:

1. Create a template for the Home Page derived from a base template.
1. Configure the Home Page template for containers, policies, and components.
1. Covert the existing home page to use the new editable template.
1. Verify the updated page.

Let's get started! 

### Exercise 1.1 - Template Evaluation

We've already reviewed the existing Geometrixx Home page and broken down the structure, identifying what is needed for the template. Let's look at a complete Home Page:
  
This is a home page filled out with all of the content. Sometimes it is easier to visualize the base components by looking at an empty page:

<p align="center">
  <img src="/images/geometrixx-empty-homepage.png" width="400px" /><br/>
  <em>Empty Geometrixx Home Page</em>
  <br/>
  <br/>
</p>


From here, you should now be able to see the break out of the components. 


<p align="center">
  <img src="/images/geometrixx-shapes-home-unannotated.png" width="400px" /><br/>
  <em>Annotated Template Structure</em>
</p>

Here's an annotated view; the components listed here are identified using the new types - not the existing components currently employed by the template. Each of these components marked on this image are _structure_ components. This means they are managed at the template and must be added to editable template, by the template author.

<p align="center">
  <img src="/images/geometrixx-shapes-home-annotated.png" width="400px" /><br/>
  <em>Annotated Template Structure</em>
</p>


One additional point to clarify, within the layout container highlighted in blue, there are additional nested structure components:

<p align="center">
 <img src="/images/geometrixx-homepage-containers.png" width="400px" /><br/>
   <em>Annotated Template Layout Container</em>
</p>


### Exercise 1.2 - Create Home Page Template

In this exercise we will create an Editable Template which supports the same structure as the legacy Static Template.

#### 1. Create Template from Base Template

Let's create what will be the new Home Page editable template. First log into AEM, use the default account: 

* Username: admin
* Password: admin

* Open the [AEM Start Page](http://localhost:4502/aem/start.html) Bookmark in Chrome.

  
<p align="center">
  <img src="/images/aem-login-screen.png" width="900px" /><br/>
  <em>AEM Login Page</em>
  <br/>
  <br/>
</p>


Navigate to the Templates folder.
  
<p align="center">
  <img src="/images/template-console-1.png" width="900px" /><br/>
  <em>Template Editor Wizard Selection</em>
  <br/>
  <br/>
</p>


Open the Geometrixx Demo template folder.
<p align="center">
  <img src="/images/template-console-2.png" width="900px" /><br/>
  <em>Geometrixx Demo Template Folder</em>
  <br/>
  <br/>
</p>

Start the Template Creation Wizard.
<p align="center">
  <img src="/images/template-console-3.png" width="900px" /><br/>
  <em>Create New Editable Template</em>
  <br/>
  <br/>
</p>

Select the based template from which to derive the new Editable Template.
<p align="center">
  <img src="/images/template-console-4.png" width="900px" /><br/>
  <em>Starting Template Selection</em>
  <br/>
  <br/>
</p>

Specify the new template's name. 
**Note: Make sure to use the name *GeoDemo Home Page*; we use it in a configuration later.**
<p align="center">
  <img src="/images/template-console-5.png" width="900px" /><br/>
  <em>Editable Template Name</em>
  <br/>
  <br/>
</p>

Open the newly created template.
<p align="center">
  <img src="/images/template-console-6.png" width="300px" /><br/>
  <em>Successful Template Creation</em>
  <br/>
  <br/>
</p>

#### 2. Update Template Policy 

We need to update the template's policy, so that the CSS rules are correctly applied. First step is to open the Page Policy dialog.

<p align="center">
  <img src="/images/homepage-template-policy-1.png" width="900px" /><br/>
  <em>Template Policy Menu</em>
  <br/>
  <br/>
</p>


Then we create a new policy, and add the *homepage* style definition.
<p align="center">
  <img src="/images/homepage-template-policy-2.png" width="900px" /><br/>
  <em>Edit Homepage Template Policy</em>
  <br/>
  <br/>
</p>


#### 3. Create new Root Layout Container Policy

Now we need to configure the root layout container to set the default/locked components, and restrict components that can be used. For this exercise, make sure you only select the components you see here in the screenshots.

First, select the layout container and open it's policy dialog.
<p align="center">
  <img src="/images/root-layout-container-policy-1.png" width="900px" /><br/>
  <em>Select Layout Container Policy</em>
  <br/>
  <br/>
</p>


Then create a new policy definition.
<p align="center">
  <img src="/images/root-layout-container-policy-2.png" width="600px" /><br/>
  <em>Create New Template Policy</em>
  <br/>
  <br/>
</p>

Once we have a new definition, we'll give it a name and add a few components from the *General* group.
<p align="center">
  <img src="/images/root-layout-container-policy-3.png" width="600px" /><br/>
  <em>New Template Policy Properties</em>
  <br/>
  <br/>
</p>


We also want to add a couple of the *Geometrixx Demo* components, as these will be structural components. 
<p align="center">
  <img src="/images/root-layout-container-policy-4.png" width="400px" /><br/>
  <em>Template Policy Allowed Components</em>
  <br/>
  <br/>
</p>


Finally, set the number of columns in the responsive grid, and save the policy.
<p align="center">
  <img src="/images/root-layout-container-policy-5.png" width="600px" /><br/>
  <em>Template Policy Responsive Settings</em>
  <br/>
  <br/>
</p>

#### 4. Define Base Structure for Template

Now that the policy is created, we can create the remaining structure for the template. This will lock specific components on the page, while enabling authors to use other components in the layout container. For this we need to be in the `Structure` mode. This is the default mode for the Template Editor. If you are not in structure mode, see the [troubleshooting steps](/troubleshooting.md) to switch modes.

##### A. Add the Header Component

In order to add components to the template, we need to open the side panel.

<p align="center">
  <img src="/images/open-sliding-browser.png" width="900px" /><br/>
  <em>Open Side Panel</em>
  <br/>
  <br/>
</p>


Now, drag the the Header component over, adding it to the root layout container. This component should only be editable by template authors.

<p align="center">
  <img src="/images/root-header-1.png" width="900px" /><br/>
  <em>Template Header Addtion</em>
  <br/>
  <br/>
</p>

Once the header is placed it appears to take up the full 16 columns. However, this is not the case - something about the non-standard column count may create issues. Therefore, refresh the page and you should see it in the default 12 column layout. (**Note: This is known bug and has been reported**)

<p align="center">
  <img src="/images/root-header-2.png" width="900px" /><br/>
  <em>Template Header Refresh</em>
  <br/>
  <br/>
</p>

Now that we can see the correct layout, we can fix it's width. Select the component and enter it's layout mode.

<p align="center">
  <img src="/images/root-header-3.png" width="900px" /><br/>
  <em>Template Header Layout Mode</em>
  <br/>
  <br/>
</p>

While in layout mode, expand the header to take up the full 16 column width. Once done, exit the layout mode.
<p align="center">
  <img src="/images/root-header-4.png" width="900px" /><br/>
  <em>Template Header Resize</em>
  <br/>
  <br/>
</p>


##### B. Add & Configure Carousel Component

Next, we'll add the Carousel to the root layout container.

<p align="center">
  <img src="/images/root-carousel-1.png" width="900px" /><br/>
  <em>Template Carousel Addition</em>
  <br/>
  <br/>
</p>


Like the header component, once the carousel is in the container it needs to be resized. So select the carousel and enter the layout mode again.
<p align="center">
  <img src="/images/root-carousel-2.png" width="900px" /><br/>
  <em>Template Carousel Layout Mode</em>
  <br/>
  <br/>
</p>
 
Resize the carousel to take up the full 16 columns, exiting layout mode once complete.
<p align="center">
  <img src="/images/root-carousel-3.png" width="900px" /><br/>
  <em>Template Carousel Resize</em>
  <br/>
  <br/>
</p>

Finally, unlock the Carousel so each page created from this template can have custom content.
<p align="center">
  <img src="/images/root-carousel-4.png" width="900px" /><br/>
  <em>Template Carousel Unlocked</em>
  <br/>
  <br/>
</p>

##### C. Add the Main Layout Container

Next we'll add the Main Layout container, drag it over below the Carousel.

<p align="center">
  <img src="/images/root-main-container-1.png" width="900px" /><br/>
  <em>Template Main Layout Container Addition</em>
  <br/>
  <br/>
</p>

This container will span 12 columns, which is the default column size in the responsive grid. It is still a good idea to force it to a specific size. So let's select the container and enter the layout mode. 
<p align="center">
  <img src="/images/root-main-container-2.png" width="900px" /><br/>
  <em>Template Main Layout Container Layout Mode</em>
  <br/>
  <br/>
</p>

To make the adjustment, we are just going to set the size to 12 columns, We don't want to adjust the width, but we do need to trigger the layout container set the width value. To do this, we move the right handle just enough to trigger the layout display, then release it locking it back into 12 columns. This will force the responsive size of the text container to be set.

<p align="center">
  <img src="/images/root-main-container-3.png" width="900px" /><br/>
  <em>Template Main Layout Container Resize</em>
  <br/>
  <br/>
</p>

##### D. Add Main Container Content & Policies

Next, we'll add the main layout container's content. This is will be a the fixed *Lead* component and a *Layout Container*, which will allow authors to add arbitrary content.


Drag the *Lead* Component over to the main layout container.
<p align="center">
  <img src="/images/main-container-content-1.png" width="900px" /><br/>
  <em>Template Main Layout Lead Addition</em>
  <br/>
  <br/>
</p>


This will have custom content per page, so let's unlock it.
<p align="center">
  <img src="/images/main-container-content-2.png" width="900px" /><br/>
  <em>Template Main Layout Lead Unlocked</em>
  <br/>
  <br/>
</p>


Now we can add the layout container that will allow authors add content and components.
<p align="center">
  <img src="/images/main-container-content-3.png" width="900px" /><br/>
  <em>Template Main Layout Container Sub-Container Addition</em>
  <br/>
  <br/>
</p>


We want to allow authors to add only specific components, and more than this template currently allows. So we'll add a custom policy to this container - open the container's policy.
<p align="center">
  <img src="/images/main-container-content-4.png" width="900px" /><br/>
  <em>Template Main Layout Container Sub-Container Policy</em>
  <br/>
  <br/>
</p>

Give the policy a descriptive name.
<p align="center">
  <img src="/images/main-container-content-5.png" width="400px" /><br/>
  <em>Template Main Layout Sub-Container New Policy</em>
  <br/>
  <br/>
</p>

Add all the entire GeoDemo component group, and then save the policy.
<p align="center">
  <img src="/images/main-container-content-6.png" width="400px" /><br/>
  <em>Template Main Layout Sub-Container Policy Components</em>
  <br/>
  <br/>
</p>

Finally, we want authors to be able to add the allowed components and add content to them, so unlock the container.
<p align="center">
  <img src="/images/main-container-content-7.png" width="900px" /><br/>
  <em>Template Main Layout Sub-Container Unlocked</em>
  <br/>
  <br/>
</p>

##### E. Add & Configure the Right Rail Layout Container

Next, we'll add the Right Rail Layout container, and configure its policy of allowed components.


First, drag over the layout container - make sure to place it in the *root* layout container, this is the 16 column wide instance.
<p align="center">
  <img src="/images/root-rightrail-container-1.png" width="900px" /><br/>
  <em>Template Right Rail Layout Container Addition</em>
  <br/>
  <br/>
</p>


To resize it, we need to enter layout mode for it.
<p align="center">
  <img src="/images/root-rightrail-container-2.png" width="600px" /><br/>
  <em>Template Right Rail Layout Container Layout Mode</em>
  <br/>
  <br/>
</p>

Resize it to be four columns wide, this will make it automatically float to sit next to the other container.
<p align="center">
  <img src="/images/root-rightrail-container-3.png" width="600px" /><br/>
  <em>Template Right Rail Layout Container Resize</em>
  <br/>
  <br/>
</p>

Like the main container, we want to allow authors to add a restricted set of components to this container. So open its policy editor.
<p align="center">
  <img src="/images/rightrail-container-policy-1.png" width="900px" /><br/>
  <em>Template Right Rail Layout Container Policy Edit</em>
  <br/>
  <br/>
</p>

Give the new policy a name.
<p align="center">
  <img src="/images/rightrail-container-policy-2.png" width="400px" /><br/>
  <em>Template Right Rail Layout Container New Policy</em>
  <br/>
  <br/>
</p>


Add the allowed components for this container and save the policy.
<p align="center">
  <img src="/images/rightrail-container-policy-3.png" width="400px" /><br/>
  <em>Template Right Rail Layout Container Policy Components</em>
  <br/>
  <br/>
</p>


And finally, unlock the container to allow authors to add content.
<p align="center">
  <img src="/images/root-rightrail-container-4.png" width="900px" /><br/>
  <em>Template Right Rail Layout Container Unlocked</em>
  <br/>
  <br/>
</p>


##### F. Add the Footer Component

The final step is to add the Footer to the root layout container. This component should only be editable by template authors.

Drag the *Footer* component to the root layout container.

<p align="center">
  <img src="/images/root-footer-1.png" width="900px" /><br/>
  <em>Template Footer Addtion</em>
  <br/>
  <br/>
</p>

Like the Header, once the footer is placed it appears to take up the full 16 columns. However, this is not the case - something about the non-standard column count may create issues. Therefore, refresh the page and you should see it in the default 12 column layout.

<p align="center">
  <img src="/images/root-footer-2.png" width="900px" /><br/>
  <em>Template Footer Refresh</em>
  <br/>
  <br/>
</p>

Now that we can see the correct layout, we can fix it's width. Select the component and enter it's layout mode.
<p align="center">
  <img src="/images/root-footer-3.png" width="600px" /><br/>
  <em>Template Footer Layout Mode</em>
  <br/>
  <br/>
</p>

While in layout mode, expand the header to take up the full 16 column width. Once done, exit the layout mode.
<p align="center">
  <img src="/images/root-footer-4.png" width="900px" /><br/>
  <em>Template Footer Resize</em>
  <br/>
  <br/>
</p>


### Exercise 1.3 - Convert a Page


Now that we have a working template, we can convert the Geometrixx home page. To do this, we'll use the Page Template/Structure Conversion Tool. This is a tool created specifically to convert from a legacy static template to an editable template, and works in three steps:

1. Convert Page Structure 
1. Convert all parsys components to responsive grids
1. Convert all column controls to a new responsive grid structure, each column is its own responsive grid.

The Page & Column control rewrite rules are configurable. For this lab we have provided the default ones necessary to convert Geometrixx column control. However, we do need to customize the configuration for the Page Rewrite Rule. Let's do that now:

#### 1. Identify Responsive Grids

Open CRX/DE and list the component names on the new Editable template.

* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) Bookmark in Chrome.

Navigate from the tree root to: 

* /conf
  * geodemo
    * settings
      * wcm
        * templates
          * geodemo-home-page
            * structure
              * jcr:content
                * root

Click on the *root* node to expand it and display the node names on the Editable Template. In this example the `responsivegrid` node represents the main parsys. The `responsivegrid_942409522` node represents the rightrail parsys. **Note: the node `responsivegrid_942409522` is unique to this example, you will have a different value in your AEM instance*

<p align="center">
 <img src="/images/template-node-structure.png" width="400px" /><br/>
  <em>Template Node Structure</em>
</p>


#### 2. Update Page Rewrite Rule Configuration

To configure the Rewrite Rule we need to update the OSGi Configuration, to do this, open the Web Console:

* Open the [OSGi Web Console](http://localhost:4502/system/console/configMgr) bookmark in Chrome.

Search for the *Page Rewrite Rule* Configuration. Click on the configuration entry labeled `com.adobe.aem.modernize.structure.impl.rules.PageRewriteRule~homepage`, and open the form.

<p align="center">
 <img src="/images/web-console-rewrite-rule.png" width="600px" /><br/>
  <em>AEM Web Console Configurations</em>
  <br/>
  <br/>
</p>

This is the pre-edited configuration form, we are going to update the `<<responsive_grid_name>>` references highlighted here:

<p align="center">
 <img src="/images/osgi-rewrite-rule-preedit.png" width="900px" /><br/>
  <em>Page Rewrite Configuration - Pre Edit</em>
  <br/>
  <br/>
</p>


Replace `<<responsive_grid_name>>`, with the name of the rightrail parsys *shown in your AEM instance*. This is an example complete form, **the numbers will be different for your updates**. Once the updates are done, save the form.

<p align="center">
 <img src="/images/osgi-rewrite-rule-postedit.png" width="600px" /><br/>
  <em>Page Rewrite Configuration - Post Edit</em>
  <br/>
  <br/>
</p>

#### 3. Use the Page Converter Tool

This will actually convert the page to use the new Editable Template. The only pages that are listed, are those which match configured *PageRewriteRule Service* definitions. At this time, this is just the Geometrixx Home Page template.

* Open the [AEM Start Page](http://localhost:4502/aem/start.html) Bookmark in Chrome.


Navigate to the Page Conversion Tool
<p align="center">
  <img src="/images/page-structure-conversion-1.png" width="900px" /><br/>
  <em>Structure Conversion Navigation</em>
  <br/>
  <br/>
</p>

Enter the Geometrixx Homepage path and run the search.
<p align="center">
  <img src="/images/page-structure-conversion-2.png" width="900px" /><br/>
  <em>Structure Conversion Page Search</em>
  <br/>
  <br/>
</p>

Select the Gemoetrixx English home page and run the conversion process!.
<p align="center">
  <img src="/images/page-structure-conversion-3.png" width="900px" /><br/>
  <em>Structure Conversion Page Selection</em>
  <br/>
  <br/>
</p>

Once the process is complete, you'll see the success message.
<p align="center">
  <img src="/images/page-structure-conversion-4.png" width="900px" /><br/>
  <em>Structure Conversion Page Success</em>
  <br/>
  <br/>
</p>

#### 4. Review Current State

After this step, the Home page has been converted. Let's take a look at it:

* Open the [Geometrixx Home Page](http://localhost:4502/editor.html/content/geometrixx/en.html) Bookmark in Chrome.



For the most part, the page looks the same, which is precisely the outcome we wanted.

<p align="center">
  <img src="/images/updated-home-page-1.png" width="900px" /><br/>
  <em>Updated Geometrixx Home Page</em>
</p>

 ***Note**:There are still some stylistic differences in the page. This is attributed to a difference in the components no longer aligning with the new page structure. Let's address this in the next lesson.*

### Next Lesson

Now that we have converted the page structure, we can convert the individual components to reference the new code we've developed.  

[Start the next Lesson.](lesson-2.md)
