# Modernizing Your Existing Adobe Experience Manager Sites Codebase

## Table of Contents

* [Lab Overview](../README.md#lab-overview)
* [Lesson 0 - Software Installation](lesson-0.md)
* [Lesson 1 - Editable Templates](lesson-1.md)
* [Lesson 2 - Component Updates](lesson-2.md)
* [Lesson 3 - Policy Updates](lesson-3.md)
* [Lesson 4 - Dialog Updates](lesson-4.md)
* [Troubleshooting Steps](../troubleshooting.md)
* [Next Steps](../next-steps.md)
* [Additional Resources](../additional-resources.md)


## Lesson 2 - Replacing Custom Components with Core Components

### Lesson Context

In this lesson we'll look at legacy components and update them to either proxy AEM Core Components, or updated (HTL) custom/customer components. To accomplish this, we'll use the new *Component Conversion Tool* for migrating component definitions.

### Scenario

The Geometrixx Shapes team realized they have a good amount of custom components on their projects, which they need to review every time AEM gets updated.

They conducted an evaluation of their components and the Core Components, and figured out they could use the latter as replacement for custom code in many situations, and guarantee reduced upgrade work in the future.


### Exercise 2.1 - Review Custom Components

In this exercise, we will review the list of custom Geometrixx components, and identify those who could be replaced with Core Components equivalent. 

* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) Bookmark in Chrome.

Navigate from the tree root to: 

* /content
  * geometrixx
    * en
      * jcr:content
        * root

Most of Geometrixx's components are from the legacy *foundation* component suite. Here are a few: 

<p align="center">
  <img src="/images/geometrixx-component-usage.png" width="400px" /><br/>
  <em>Geometrixx Home Page Component Tree</em>
  <br/>
  <br/>
</p>

1. Geometrixx Header: `geometrixx/components/header`
2. Foundation Carousel: `foundation/components/carousel`
3. Geometrixx Lead : `geometrixx/components/lead`
3. Foundation Image: `foundation/components/image`
4. Geometrixx Title: `geometrixx/components/title`
5. Foundation Text: `foundation/components/text`

Looking over this list, we want to update the following components to the specified references. Each of these are either new custom components or Core Component proxies. We provided the target source code in this lab, so there's no code to create/update.


* Geometrixx Header: `geometrixx/components/header`
  * Convert to GeoDemo Header: `geodemo/components/content/header`  
* Foundation Image: `foundation/components/image`
  * Convert to GeoDemo Image: `geodemo/components/content/image`
* Geometrixx Lead: `geometrixx/components/lead`
  * Convert to GeoDemo Lead: `geodemo/components/content/lead` 
* Geometrixx Title: `geometrixx/components/title`
  * Convert to GeoDemo Title: `geodemo/components/content/title` 
* Foundation Text: `foundation/components/text`
  * Convert to GeoDemo Header: `geodemo/components/content/text`


### Exercise 2.2 - Review Component Rewrite Rules

Since many organizations can have a large number of components, the *Component Conversion Tool* only displays components as long as they match a rule. This will help the conversion process by limiting options and allowing you to convert components in batches, as desired.

 This cuts down on the size of the list, so as not to display components which will never be modified. 

We have already provided the rules that will make the changes for updating these components. Let's review them:

You can view them in CRX/DE:

* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) bookmark in Chrome.

Navigate from the tree root to: 

* /apps
  * cq
    * modernize
      * component
        * rules
          * geodemo


#### Anatomy of a Rule:

Lets take a close look at one of the rules. Each of the rules consists of two parts, a list of `patterns` and a `replacement`.

<p align="center">
  <img src="/images/component-rewrite-rule.png" width="600px"/><br />
  <em>Component Rewrite Rule Structure</em>
  <br/>
  <br/>
</p>


##### Patterns

Each node under `patterns` is essentially a structure that must match for this rule to be applied. A rule may have multiple patterns, if any of the patterns match, then the rule will be applied.

<p align="center">
  <img src="/images/component-rewrite-rule-pattern.png" width="600px" /><br/>
  <em>Component Rewrite Rule Pattern Properites</em>
  <br/>
  <br/>
</p>

In order to match, each of the properties, child nodes, and properties must match. In this case, the following must be true:

1. Node is of primary type *nt:unstructured*
2. Node has the property `sling:resourceType` set to *foundation/components/image* 

##### Replacement

No matter how many patterns exist, there is only one replacement. This is used as the basis for writing the replacement node. There are a number of replacement rules, we won't need all of them for this lab, for more information see the HelpX page for the Conversion Tool.

Let's go through the configuration of this replacement:

<p align="center">
  <img src="/images/component-rewrite-rule-replacement.png" width="600px" /><br/>
  <em>Component Rewrite Rule Replacement Properites</em>
  <br/>
  <br/>
</p>

1. Set the node's primary type to the static value *nt:unstructured*
2. Set the `sling:resourceType` property to the static value *geodemo/components/content/image*
3. Set the `fileReference` property to the original node's `fileReference` property  
4. Set the `width` property to the original node's `width` property
5. Copy any children nodes from the original to the updated node.
    i. In the case of this *Image* component, there may be a binary file stored on the component. This last configuration will copy any files to the updated node.
 

### Exercise 2.3 - Convert the Components!

Now that we've reviewed the conversion rules, we are confident that we can use the Component Conversion tool. Let's open it up:

* Open the [AEM Start Page](http://localhost:4502/aem/start.html) Bookmark in Chrome.

Navigate to the Component Converter Tool.
<p align="center">
  <img src="/images/component-conversion-1.png" width="900px" /><br/>
  <em>Component Converter Navigation</em>
  <br/>
  <br/>
</p>

We need to search for the components to convert. We only want to convert the components on the Geometrixx Home page, so specify its `jcr:content` node - otherwise it will list all of the children pages' components as well.

<p align="center">
  <img src="/images/component-conversion-2.png" width="900px" /><br/>
  <em>Component Converter Search</em>
  <br/>
  <br/>
</p>

This list looks correct for our rules and the components we want to update. Let's run it!

<p align="center">
  <img src="/images/component-conversion-3.png" width="900px" /><br/>
  <em>Component Converter Selection</em>
  <br/>
  <br/>
</p>

Once the conversion is done, you'll get the success message.
<p align="center">
  <img src="/images/component-conversion-4.png" width="900px" /><br/>
  <em>Component Converter Success</em>
  <br/>
  <br/>
</p>


### Exercise 2.4 - Review the Final Page

Let's take a look at the full page final output now:

* Open the [Geometrixx Home Page](http://localhost:4502/editor.html/content/geometrixx/en.html) Bookmark in Chrome.

<p align="center">
  <img src="/images/updated-home-page-1.png" width="900px" /><br/>
  <em>Completed Component Conversion Home Page</em>
  <br/>
  <br/>
</p>


There's no obvious visual distinction using the new components, which is exactly the outcome we were looking for. If we take a closer look at the nodes in the repository, we can see they are now using the updated references:

* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) bookmark in Chrome.

Navigate from the tree root to: 

* /content
  * geometrixx
    * en
      * jcr:content
        * root

Example:

<p align="center">
  <img src="/images/updated-lead-component.png" width="900px" /><br/>
  <em>Updated Lead Component Node</em>
  <br/>
  <br/>
</p>

### Next Lesson

  Now that we have converted all of the components, we can update some policies and finally fix those incorrect titles.  

[Start the next Lesson.](lesson-3.md)

