# Modernizing Your Existing Adobe Experience Manager Sites Codebase

## Table of Contents

* [Lab Overview](../README.md#lab-overview)
* [Lesson 0 - Software Installation](lesson-0.md)
* [Lesson 1 - Editable Templates](lesson-1.md)
* [Lesson 2 - Component Updates](lesson-2.md)
* [Lesson 3 - Policy Updates](lesson-3.md)
* [Lesson 4 - Dialog Updates](lesson-4.md)
* [Troubleshooting Steps](../troubleshooting.md)
* [Next Steps](../next-steps.md)
* [Additional Resources](../additional-resources.md)

## Lesson 3 - Policy Updates

### Lesson Context

This lesson reviews existing *Design Mode* configurations of a site which is implemented using *Static Templates* and how to migrate them to *Editable Templates* as *Content Policies*.

### Scenario

While upgrading their Static Templates to the new AEM Editable Templates, the Geometrixx Shapes team figured out they will spend time recreating configurations. However, that work could be automated.

To assist them, we are going to:

1. Evaluate the former design
1. Import design configurations as policies
1. Apply policies on editable templates

### Exercise 3.1 - Design Evaluation

While converting the former Geometrixx Home page's template, we noticed we had to re-create configurations that were previously stored in the Design Mode. This design is applied to the root page of the site via the `cq:designPath` property. However, since the property serves no purpose on the new template configurations, it is removed during the page conversion process. We can still review the content of the old configurations.

When looking at the Geometrixx Design, you can observe it contains:

* General styling for the website (CSS files, icon, images)
* Client libraries definition
* Design configurations

* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) bookmark in Chrome.

Navigate from the tree root to: 

* /etc
  * designs
    * geometrixx
  
<p align="center">
  <img src="/images/design-review-1.png" /><br/>
  <em>Geometrixx Design Configuration Contents</em>
  <br/>
  <br/>
</p>

Under the geometrixx design’s `jcr:content` node, we can see a separate node for each type of page in the Geometrixx site implementation.  Drilling down into each of these page type’s will show us the hierarchy of components that is allowed on these pages as well as the configurations that have been set in each component’s design dialog.

* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) bookmark in Chrome.

Navigate from the tree root to: 

* /etc
  * designs
    * geometrixx
      * jcr:content

<p align="center">
  <img src="/images/design-review-2.png" /><br/>
  <em>Geometrixx Design Configuration Details</em>
  <br/>
  <br/>
</p>


### Exercise 3.2 - Review Style Components

We already converted a number of components on the pages from the legacy foundation types, to new GeoDemo components.  Now, we need to migrate the policies - this process applies the same rewrite capabilities as the previous Components Converter. This is necessary as Policies are referenced by sling resource type, not by page/container path.

 
In this exercise, let's first look at the existing design configuration that we'll be updating. We'll start with the *Title* Component Style.

* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) bookmark in Chrome.

Navigate from the tree root to: 

* /etc
  * designs
    * geometrixx
      * jcr:content
        * page
          * par
            * title 

Most of Geometrixx's components are from the legacy *foundation* component suite. Here is an example: 

<p align="center">
  <img src="/images/title-design-node.png" /><br />
  <em>Geometrixx Home Page Parsys Title Design</em>
  <br/>
  <br/>
</p>

Just like in the Component Conversion, we'll be updating this component with the following rule:


* Geometrixx Title: `geometrixx/components/title`
  * Convert to GeoDemo Title: `geodemo/components/content/title` 

### Exercise 3.3 - Review Component Rewrite Rules


Again, similar to the *Component Conversion Tool* the *Policy Importer/Conversion Tool* only displays components as long as they match a rule. This will help the conversion process by limiting options and allowing you to convert components in batches, as desired.

We have already provided the rules that will make the changes for updating these components. Let's review them.

* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) bookmark in Chrome.

Navigate from the tree root to: 

* /apps
  * cq
    * modernize
      * design
        * rules
          * geodemo

<p align="center">
  <img src="/images/policy-import-rules.png" width="400px" /><br />
  <em>Geometrixx Home Page Parsys Title Design</em>
  <br/>
  <br/>
</p>

The component rewrite rules are written in the same way as the component rewrite rules that we reviewed in the previous lesson, so we won’t discuss them again.


### Exercise 3.4 - Extract Policies

In this exercise we will extract existing configurations from former design, and turn them info Content Policies that could be reused on editable templates.

Let's run the tool and select the page design components we want to import. 

* Open the [AEM Start Page](http://localhost:4502/aem/start.html) Bookmark in Chrome.

Navigate to the Policy Importer tool.
<p align="center">
  <img src="/images/policy-importer-1.png" width="900px" /><br/>
  <em>Policy Importer Navigation</em>
  <br/>
  <br/>
</p>

We only want to convert the components from Geometrixx Design, the only components displayed will be those with a rule defined. Search for the available styles within the specified design.

<p align="center">
  <img src="/images/policy-importer-2.png" width="900px" /><br/>
  <em>Policy Importer Style Search</em>
  <br/>
  <br/>
</p>

To reduce the list of styles after the conversion, only select the styles for the page's parsys and title components, as shown here. Make sure to select the target Policy location for the import, otherwise you will get a failure.
<p align="center">
  <img src="/images/policy-importer-3.png" width="900px" /><br/>
  <em>Policy Importer Style Selection</em>
  <br/>
  <br/>
</p>

Once we're done, the success message will be displayed.
<p align="center">
  <img src="/images/policy-importer-4.png" width="900px" /><br/>
  <em>Policy Importer Process Complete</em>
  <br/>
  <br/>
</p>

### Exercise 3.5 - Review Created Policies

Once the tool runs successfully, we can review how those policies have been imported.

#### 1. Location

Policies have been stored in the location defined while running the conversion tool.

* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) bookmark in Chrome.

Navigate from the tree root to: 

* /conf
  * geodemo
    * settings
      * wcm
        * policies

<p align="center">
  <img src="/images/policy-location.png" width="400px" /><br/>
  <em>GeoDemo Policy</em>
  <br/>
  <br/>
</p>

#### 2. Conversion Rules

Some components have been configured with specific conversion rules.

Paragraph system is one of those. Former configurations get converted into Layout Container configurations.

Observe once more the definition of the Geometrixx Design for content pages:
  
* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) bookmark in Chrome.
 
Navigate from the tree root to: 
 
 * /etc
   * designs
     * geometrixx
       * jcr:content
         * homepage
           * par

<p align="center">
  <img src="/images/geometrixx-homepage-par-design.png" /><br/>
  <em>Geometrixx Homepage Parsys Design Configuration</em>
  <br/>
  <br/>
</p>

Now look at how that policy got converted into a Layout Container configuration.

* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) bookmark in Chrome.
 
Navigate from the tree root to: 
 
 * /conf
   * geodemo
     * settings
       * wcm
         * policies
           * wcm
            * foundation
              * components
                * responsivegrid

<p align="center">
  <img src="/images/geodemo-homepage-responsivegrid-importerd-design.png" /><br/>
  <em>GeoDemo Converted Reponsive Grid Policy</em>
  <br/>
  <br/>
</p>

### Exercise 3.6 - Apply Policies

In this exercise we will apply an imported policy on our template. The intent of this is to fix those pesky titles being incorrectly formatted. 

* Open the [Geometrixx Home Page Template](http://localhost:4502/editor.html/conf/geodemo/settings/wcm/templates/geodemo-home-page/structure.html) bookmark in Chrome.


Edit the Title's policy configuration on the original template.
<p align="center">
  <img src="/images/policy-apply-1.png" /><br/>
  <em>Homepage Title Policy Edit</em>
  <br/>
  <br/>
</p>

Select the newly created policy and save form.
<p align="center">
  <img src="/images/policy-apply-2.png" /><br/>
  <em>Homepage Title Policy Selection & Save</em>
  <br/>
  <br/>
</p>

And now that we've applied the policy, we can refresh the Geometrixx Home page and see the titles have the correct default styles applied.

* Open the [Geometrixx Home Page](http://localhost:4502/editor.html/content/geometrixx/en.html) Bookmark in Chrome.

<p align="center">
  <img src="/images/fully-updated-geometrixx-homepage.png" /><br/>
  <em>Completed Geometrixx Home Page</em>
  <br/>
  <br/>
</p>


### Next Lesson

We've now converted all of the styles and applied our policies, but we've left some old dialogs lying around. Let's update those next.

[Start the next Lesson.](lesson-4.md)