# Modernizing Your Existing Adobe Experience Manager Sites Codebase

## Table of Contents


* [Lab Overview](README.md#lab-overview)
* [Lesson 0 - Software Installation](lessons/lesson-0.md)
* [Lesson 1 - Editable Templates](lessons/lesson-1.md)
* [Lesson 2 - Component Updates](lessons/lesson-2.md)
* [Lesson 3 - Policy Updates](lessons/lesson-3.md)
* [Lesson 4 - Dialog Updates](lessons/lesson-4.md)
* [Troubleshooting Steps](troubleshooting.md)
* [Next Steps](next-steps.md)
* [Additional Resources](additional-resources.md)

## Troubleshooting The Lab

There are a few places where something may go wrong during the lab, and you may need to backtrack to fix it. This information should help with the most likely issues that may be encountered.


### Wrong Template Editor Mode

#### Issue

The first possible, albeit highly unlikely, issue that may be experienced is the inability to add components to the newly created Editable Template. This can occur if you are not in the `Structure` mode. 

Instead, you may find yourself in `Layout` Mode:

<p align="center">
  <img src="/images/template-layout-mode.png" width="900px" /><br/>
  <em>Template Layout Mode</em>
  <br/>
  <br/>
</p>

Or possibly `Initial Content` mode:

<p align="center">
  <img src="/images/template-initial-content-mode.png" width="900px" /><br/>
  <em>Template Initial Content Mode</em>
  <br/>
  <br/>
</p>

Or finally, `Preview` mode:

<p align="center">
  <img src="/images/template-preview-mode.png" width="900px" /><br/>
  <em>Template Preview Mode</em>
  <br/>
  <br/>
</p>

#### Resolution

To resolve this, simply change modes back to `Structure` by selecting it from the mode menu.

<p align="center">
  <img src="/images/template-change-mode-menu.png" width="900px" /><br/>
  <em>Change Template Mode Menu</em>
  <br/>
  <br/>
</p>

### Missing Right Rail After Conversion

#### Issue
After the conversion, the right rail is not displayed:

<p align="center">
  <img src="/images/missing-right-rail.png" width="900px" /><br/>
  <em>Right Rail Missing</em>
  <br/>
  <br/>
</p>

#### Resolution

This occurs when the name of the right rail parsys was not set correctly in the OSGi configuration. It is not essential for the lab that it be correct, so we are not providing a resolution. 


### Page Conversion Fails

#### Issue
Another issue which you may encounter is an error during the Page Conversion process. This produces an error which appears as:

<p align="center">
  <img src="/images/page-conversion-error.png" width="900px" /><br/>
  <em>Page Coversion Error</em>
  <br/>
  <br/>
</p>

#### Resolution

This occurs when the one of the updates to the Page Rewrite Rule configuration was missed, ensure *both* values are updated here:

<p align="center">
 <img src="/images/osgi-rewrite-rule-preedit.png" width="900px" /><br/>
  <em>TextEdit PageRewriteRule File</em>
  <br/>
  <br/>
</p>


### Invalid Page after Update

#### Issue
After the conversion, if your page does not appear as you expect, it probably looks something like this:

<p align="center">
  <img src="/images/page-wrong-template-name.png" width="900px" /><br/>
  <em>Page with Missing Template</em>
  <br/>
  <br/>
</p>

You can see that the header and footer are missing. The columns are not in the correct locations, and none of the updated styles are applied. This occurs when the template name does not match up to the steps in this workbook. 

#### Resolution

If you encounter this issue at Summit, ask for assistance from a TA and take the following steps:

1. Open the Terminal App
 
2. Reinstall the provided Geometrixx Demo content.

```sh

$ cd ~/Desktop/Summit-2019/packages

$ mvn com.day.jcr.vault:content-package-maven-plugin:install -Dvault.file=./cq-geometrixx-pkg-5.11.11-SNAPSHOT.zip

```

3. Identify the path to the created template.

* Open the [CRX/DE Lite](http://localhost:4502/crx/de/index.jsp) Bookmark in Chrome.

Navigate to the Template location under `/conf` and get the full path to the created template. This is likely different than what is shown in this screenshot, as this is only an *example*.
<p align="center">
 <img src="/images/template-crx-path.png" width="900px" /><br/>
  <em>Editable Home Page Template Path</em>
  <br/>
  <br/>
</p>


4. Update the Page Rewrite Rule OSGI Configuration

* Open the [OSGi Web Console](http://localhost:4502/system/console/configMgr) bookmark in Chrome.

Search for the *Page Rewrite Rule* Configuration. Click on the configuration entry labeled `com.adobe.aem.modernize.structure.impl.rules.PageRewriteRule~homepage`, and open the form.

<p align="center">
 <img src="/images/web-console-rewrite-rule.png" width="600px" /><br/>
  <em>AEM Web Console Configurations</em>
  <br/>
  <br/>
</p>


The path to the template is a property of the OSGi Configuration.

<p align="center">
 <img src="/images/osgi-rewrite-rule-preedit-template.png" width="900px" /><br/>
  <em>Page Rewrite Configuration - Pre Edit</em>
  <br/>
  <br/>
</p>

Change the value to the correct path - take the value identified in the previous step, and update the configuration.

<p align="center">
 <img src="/images/osgi-rewrite-rule-postedit-template.png" width="900px" /><br/>
  <em>Page Rewrite Configuration - Post Edit</em>
  <br/>
  <br/>
</p>


5. Re-Execute the Page Conversion. 

Return to the `Page Converter Tool` and follow Lesson 1, Exercise 1.3, Step 3. The converson should complete and the page should display correctly.


### Policy Import Fails

#### Issue
If you encounter an error during your policy import, it may appear like this:

<p align="center">
  <img src="/images/policy-import-error.png" width="900px" /><br/>
  <em>Policy Import Error</em>
  <br/>
  <br/>
</p>

#### Resolution

You will see this error if you forgot to specify the target location for the new policies. 

<p align="center">
  <img src="/images/policy-import-target-missing.png" width="900px" /><br/>
  <em>Policy Import Target Missing</em>
  <br/>
  <br/>
</p>


Make sure you provide a value in the import target field:

<p align="center">
  <img src="/images/policy-import-target-specified.png" width="900px" /><br/>
  <em>Policy Import Target Provided</em>
  <br/>
  <br/>
</p>


